# parts: gc03

- GC03, recordable sound module, diymore
- https://manuals.plus/ae/1005007700106481

|   |
| --- |
| ![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/gc03.png?raw=true) |
